==> warskald-0.0.27-py3-none-any.whl: warskald/ws_config.py <==
import configparser
import json
import os
import toml
import yaml

from configparser import MissingSectionHeaderError
from typing import Any
from warskald import utils

ENV_PROPS_DIR = os.environ.get('ENV_PROP_DIR')

class SimpleConfigParser(configparser.ConfigParser):
    def read(self, filenames, encoding=None):
        
        if isinstance(filenames, str):
            filenames = [filenames]
        for filename in filenames:
            with open(filename, 'r', encoding=encoding) as config_file:
                content = config_file.read()
                content = '[dummy_section]\n' + content
                
                self.read_string(content)
                
class ConfigReader:
    def __init__(self, config_path: str) -> None:
        self.config_data: dict = None
        self._parse_config(config_path)
    
    def _parse_config(self, config_path: str):
        
        config_data, cfg_type = self._read_config(config_path)
        self.config_data = {}
        
        if(isinstance(config_data, configparser.ConfigParser)):
            for section in config_data.sections():
                if(section != 'dummy_section'):
                    self.config_data[section] = {}
                for key, value in config_data.items(section):
                    if(utils.not_empty(value)):
                        if(section == 'dummy_section'):
                            self.config_data[key] = value
                        else:
                            self.config_data[section][key] = value
                    
        
                
        elif(cfg_type == 'dict'):
            self.config_data = config_data
    
    def _read_config(self, config_path: str):
        _, ext = os.path.splitext(config_path)
        
        if ext == '.json':
            with open(config_path, 'r') as file:
                return json.load(file), 'dict'
            
        elif ext == '.ini':
            try:
                config = configparser.ConfigParser()
                config.read(config_path)
                return config, 'configparser'
            except MissingSectionHeaderError:
                config = SimpleConfigParser()
                config.read(config_path)
                return config, 'SimpleConfigParser'
            
        elif ext in ['.properties', '.conf']:
            config = SimpleConfigParser()
            config.read(config_path)
            
            return config, 'SimpleConfigParser'
        
        elif ext == '.yaml' or ext == '.yml':
            with open(config_path, 'r') as file:
                return yaml.safe_load(file), 'dict'
            
        elif ext == '.toml':
            with open(config_path, 'r') as file:
                return toml.load(file), 'dict'
            
        else:
            raise ValueError(f'Unsupported config file extension: {ext}')
                
class EnvPropsReader:
    def __init__(self):
        self.config = {}
        env_prop_files = os.listdir(ENV_PROPS_DIR)
        
        self._parse_configs([os.path.join(ENV_PROPS_DIR, file) for file in env_prop_files])
    
    def _parse_configs(self, file_paths: list[str]):
        
        for file_path in file_paths:
            config = ConfigReader(file_path).config_data
            #print(config)
            if(isinstance(config, dict)):
                for key, value in config.items():
                    #if(utils.not_empty(value)):
                    self.config[key] = value
            
    def get(self, path: str | list[str], default_val: Any = None) -> Any:
        return utils.get_nested(self.config, path, default_val)

==> warskald-0.0.31-py3-none-any.whl: warskald/ws_config.py <==
import configparser
import json
import os
import toml
import yaml

from configparser import MissingSectionHeaderError
from typing import Any
from warskald import utils, AttrDict

ENV_PROPS_DIR = os.environ.get('ENV_PROP_DIR')

class SimpleConfigParser(configparser.ConfigParser):
    def read(self, filenames, encoding=None):
        
        if isinstance(filenames, str):
            filenames = [filenames]
        for filename in filenames:
            with open(filename, 'r', encoding=encoding) as config_file:
                content = config_file.read()
                if(not content.startswith('[dummy_section]')):
                    content = '[dummy_section]\n' + content
                
                self.read_string(content)
                
class ConfigReader:
    def __init__(self, config_path: str) -> None:
        self.config_data: AttrDict = AttrDict()
        self._parse_config(config_path)
    
    def _parse_config(self, config_path: str):
        
        config_data, cfg_type = self._read_config(config_path)
        self.config_data = AttrDict({})
        
        if(isinstance(config_data, configparser.ConfigParser)):
            for section in config_data.sections():
                if(section != 'dummy_section'):
                    self.config_data[section] = {}
                for key, value in config_data.items(section):
                    if(utils.not_empty(value)):
                        if(section == 'dummy_section'):
                            self.config_data[key] = value
                        else:
                            self.config_data[section][key] = value
                   
        elif(cfg_type == 'dict'):
            self.config_data = AttrDict(config_data)
    
    def _read_config(self, config_path: str):
        _, ext = os.path.splitext(config_path)
        
        if ext == '.json':
            with open(config_path, 'r') as file:
                return json.load(file), 'dict'
            
        elif ext == '.ini':
            try:
                config = configparser.ConfigParser()
                config.read(config_path)
                return config, 'configparser'
            except MissingSectionHeaderError:
                config = SimpleConfigParser()
                config.read(config_path)
                return config, 'SimpleConfigParser'
            
        elif ext in ['.properties', '.conf']:
            config = SimpleConfigParser()
            config.read(config_path)
            
            return config, 'SimpleConfigParser'
        
        elif ext == '.yaml' or ext == '.yml':
            with open(config_path, 'r') as file:
                return yaml.safe_load(file), 'dict'
            
        elif ext == '.toml':
            with open(config_path, 'r') as file:
                return toml.load(file), 'dict'
            
        else:
            raise ValueError(f'Unsupported config file extension: {ext}')
                
class EnvironmentProps:
    def __init__(self):
        self.config = AttrDict({})
        env_prop_files = os.listdir(ENV_PROPS_DIR)
        
        self._parse_configs([os.path.join(ENV_PROPS_DIR, file) for file in env_prop_files])
    
    def _parse_configs(self, file_paths: list[str]):
        
        for file_path in file_paths:
            config = ConfigReader(file_path).config_data
            #print(config)
            if(isinstance(config, dict)):
                for key, value in config.items():
                    #if(utils.not_empty(value)):
                    self.config[key] = value
            
    def get(self, path: str | list[str], default_val: Any = None) -> Any:
        value = utils.get_nested(self.config, path, default_val)
        if(isinstance(value, dict)):
            return AttrDict(value)
        return value
    
    def set(self, cfg_file: str, key: str | list[str], value: Any):
        path = os.path.join(ENV_PROPS_DIR, cfg_file)
        if(not os.path.exists(path)):
            raise FileNotFoundError(f'Config file not found: {path}')
        
        if(isinstance(key, str)):
            key = key.split('.')
        
        if(isinstance(key, list)):
            ext = os.path.splitext(path)[1]
            
            if(ext == '.json'):
                with open(path, 'r') as file:
                    data = json.load(file)
                
                utils.set_nested(data, key, value)
                
                with open(path, 'w') as file:
                    json.dump(data, file)
                    
            elif(ext == 'toml'):
                with open(path, 'r') as file:
                    data = toml.load(file)
                
                utils.set_nested(data, key, value)
                
                with open(path, 'w') as file:
                    toml.dump(data, file)
                    
            elif(ext == '.yaml' or ext == '.yml'):
                with open(path, 'r') as file:
                    data = yaml.safe_load(file)
                
                utils.set_nested(data, key, value)
                
                with open(path, 'w') as file:
                    yaml.dump(data, file)
                    
            elif(ext == '.ini' or ext == '.properties' or ext == '.conf'):
                config = SimpleConfigParser()
                config.read(path)
                
                if(len(key) == 1):
                    config[key[0]] = value
                else:
                    config[key[0]][key[1]] = value
                
                with open(path, 'w') as file:
                    config.write(file)
